==> dnet-openaireplus-workflows-5.3.7-20160620.111530-3-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/index/SwitchIndexesJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.index;

import java.util.Queue;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;
import eu.dnetlib.msro.rmi.MSROException;
import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * SwitchIndexesJobNode guides the index switches on all search services whose ids are in the queue available in the parameter named 'searchService_ids'.
 * @see eu.dnetlib.msro.openaireplus.workflows.nodes.index.FindSearchServicesJobNode
 * @see eu.dnetlib.msro.openaireplus.workflows.nodes.index.SwitchIndexJobNode
 * 
 * @author claudio, alessia
 * 
 */
public class SwitchIndexesJobNode extends SimpleJobNode {

	private static final Log log = LogFactory.getLog(SwitchIndexesJobNode.class);

	private String xqueryForServiceIdParam;

	@Override
	protected String execute(final NodeToken token) throws Exception {
		Queue<String> q = (Queue<String>) token.getEnv().getTransientAttribute("searchService_ids");
		if(q == null) throw new MSROException("Transient param 'searchService_ids' with queue of string could not be found");
		if(q.isEmpty()) {
			log.info("searchService_ids queue consumed, now ending cycle");
			return Arc.DEFAULT_ARC;
		}
		else{
			//we have something to do: setting the xqueryForServiceIdParam for the SwitchIndexJobNode
			String id = q.poll();
			String xquery = "/RESOURCE_PROFILE[./HEADER/RESOURCE_IDENTIFIER/@value = '"+id+"']";
			token.getEnv().setAttribute(getXqueryForServiceIdParam(), xquery);
			//updating the queue for next iteration
			token.getEnv().setTransientAttribute("searchService_ids", q);
			return "switch";
		}
	}
	

	public String getXqueryForServiceIdParam() {
		return xqueryForServiceIdParam;
	}

	public void setXqueryForServiceIdParam(final String xqueryForServiceIdParam) {
		this.xqueryForServiceIdParam = xqueryForServiceIdParam;
	}

}

==> dnet-openaireplus-workflows-5.3.7-20160620.141013-7-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/index/SwitchIndexesJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.index;

import java.util.Queue;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;
import eu.dnetlib.msro.rmi.MSROException;
import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * SwitchIndexesJobNode guides the index switches on all search services whose ids are in the queue available in the parameter named 'searchService_ids'.
 * @see eu.dnetlib.msro.openaireplus.workflows.nodes.index.FindSearchServicesJobNode
 * @see eu.dnetlib.msro.openaireplus.workflows.nodes.index.SwitchIndexJobNode
 * 
 * @author claudio, alessia
 * 
 */
public class SwitchIndexesJobNode extends SimpleJobNode {

	private static final Log log = LogFactory.getLog(SwitchIndexesJobNode.class);

	private String xqueryForServiceIdParam;

	@Override
	protected String execute(final NodeToken token) throws Exception {
		Queue<String> q = (Queue<String>) token.getEnv().getTransientAttribute("searchService_ids");
		log.debug("Got the searchService_ids queue: "+q.toString());
		if(q == null) throw new MSROException("Transient param 'searchService_ids' with queue of string could not be found");
		if(q.isEmpty()) {
			log.info("searchService_ids queue consumed, now ending cycle");
			return Arc.DEFAULT_ARC;
		}
		else{
			//we have something to do: setting the xqueryForServiceIdParam for the SwitchIndexJobNode
			String id = q.poll();
			log.debug("Polled id: "+id);
			log.debug("And now the queue is "+q);
			String xquery = "/RESOURCE_PROFILE[./HEADER/RESOURCE_IDENTIFIER/@value = '"+id+"']";
			token.getEnv().setAttribute(getXqueryForServiceIdParam(), xquery);
			log.debug("Asking to switch on profile identified by: "+xquery);
			//updating the queue for next iteration
			token.getEnv().setTransientAttribute("searchService_ids", q);
			return "switch";
		}
	}


	public String getXqueryForServiceIdParam() {
		return xqueryForServiceIdParam;
	}

	public void setXqueryForServiceIdParam(final String xqueryForServiceIdParam) {
		this.xqueryForServiceIdParam = xqueryForServiceIdParam;
	}

}
